Django-CV Documentation — Django-CV 0.0.1 documentation

# Django-CV Documentation

## Overview

Django-CV allows users to make highly customizable curricula vitae for use on their websites. The application provides models for common entries on curricula vitae such as education, employment, publications, teaching, and service. Django-CV eliminates many of the repetitive tasks related to producing curricula vitae. The included templates provide a complete CV “out of the box”, but allows researchers who might be interested to customize the format using Django templating language.

## Organization of the Documentation

- CV Sections documents the API to write lines on CV by different sections on a CV

  > - Education & Employment
  > - Publications ( Articles | Books | Chapters | Reports)
  > - Grants
  > - Talks
  > - Public writing
  > - Teaching
  > - Service

- Templates

  > - Template tags & filters
  > - Template structure

- Settings

- Module Reference

## Contributing to Django-CV

It’s quite possible that Django-CV does not include all types of publications necessary. You may open an issue, or–even better–contribute code for other common types of publications not already incorporated into Django-CV.

## Indices and tables

- Index
- Module Index
- Search Page

## Documentation Contents

- Sections
  - Publications
    - Common Features
      - Common Fields
      - Ordering
      - Common Managers
    - Authorship Sets
    - Types of Publications
      - Articles
      - Books
      - Chapters
      - Reports
  - Talks
    - Talks
      - Talk Views
    - Presentations
- Shortcuts
- Settings
  - `CV_PUBLICATION_STATUS_CHOICES`
  - `CV_FILE_TYPES_CHOICES`
  - `CV_STUDENT_LEVELS_CHOICES`
  - `CV_SERVICE_TYPES_CHOICES`
  - `CV_KEY_CONTRIBUTORS_LIST`
- Reference
  - `cv.models`
  - `cv.views`
  - `cv.tests`
    - Models